#
# spec file for package namecoin
#
# Copyright (c) 2013-2016 Peter Conrad
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:		namecoin
Version:	0.3.80
Release:	2%{?dist}.1
License:	MIT
Summary:	P2P digital currency
Url:		http://namecoin.info/
Group:		Productivity/Networking/Other
Source:		https://github.com/namecoin/namecoin/archive/nc%{version}.tar.gz
Source1:	%{name}.desktop
Source2:	%{name}d-safe
Source3:	%{name}d.apparmor
# PATCH-FIX-UPSTREAM: conrad@quisquis.de
Patch:		namecoin-fixes.patch
# From http://pastebin.com/3nN9VYx2
Patch2:		fc20-openssl-ecc.patch
# https://github.com/namecoin/namecoin/pull/213
Patch3:		namecoin-openssl101k-fix.patch
Patch4:		cxx11.patch
BuildRequires:	boost-devel libcurl-devel
%if 0%{?suse_version} > 0
BuildRequires:	libminiupnpc-devel
BuildRequires:	qrencode-devel
BuildRequires:	libjansson-devel
BuildRequires:	libdb-4_8-devel
BuildRequires:	apparmor-parser
BuildRequires:	update-desktop-files
BuildRequires:	libqt4-devel
%else
%if 0%{?fedora} > 0
BuildRequires:	miniupnpc-devel
BuildRequires:	qrencode-devel
BuildRequires:	libdb4-cxx-devel
BuildRequires:	jansson-devel
%else
BuildRequires:	gcc-c++
BuildRequires:	db4-devel
BuildRequires:	libjansson-devel-static
%endif
%if 0%{?fedora} < 20
BuildRequires:	libopenssl-ecc-devel
%else
BuildRequires:  pkgconfig(openssl) >= 1.0.0
BuildRequires:  pkgconfig(openssl) < 1.1
%endif
BuildRequires:	qt-devel
%endif
BuildRoot:	%{_tmppath}/%{name}-%{version}-build

%description
Namecoin is a decentralized key/value registration and transfer system based
on Bitcoin technology.

It can be used for multiple purposes, for example a secure and censorship
resistant replacement for DNS.

Ownership of a name is based on ownership of a coin, which is in turn based
on public key cryptography. The namecoin network reaches consensus every
few minutes as to which names have been reserved or updated.

This package contains the daemon only.

Please send donations to package maintainer: NJ4c5CDJCptVjSf1uXA7Xr9ZP65aZmudvZ

%package gui
Summary:	GUI application for Namecoin
Group:		Productivity/Networking/Other

%description gui
Namecoin is a decentralized key/value registration and transfer system based
on Bitcoin technology.

This package contains the gui application and desktop integration.

Please send donations to package maintainer: NJ4c5CDJCptVjSf1uXA7Xr9ZP65aZmudvZ

%prep
%setup -q -n namecoin-legacy-nc%{version}
%patch -p1
%if 0%{?fedora} >= 20
%patch2 -p1
%endif
%patch3 -p0
%patch4 -p1
# Fix for newer miniupnp:
%__sed -i '/0, "TCP/s/0)/0, "0")/' src/net.cpp
if grep 'define.*MINIUPNPC_API_VERSION.*1[4-9]' /usr/include/miniupnpc/miniupnpc.h; then
    %__sed -i '/upnpDiscover/s/&error/2, &/' src/net.cpp
fi
# Don't link against static libs!
%__sed -i 's/-Wl,-Bstatic//' *-qt.pro src/Makefile
# Exclude unused libs from linking
%__sed -i '/lrt/d' *-qt.pro
%if 0%{?suse_version} > 0
%__sed -i '/.-l \(z\|boost_chrono\|dl\|gthread\)/d' src/Makefile
%else
%__sed -i '/.-l \(boost_chrono\|gthread\)/d' src/Makefile
%if 0%{?fedora} < 20
%__sed -i 's,INCLUDEPATHS=,&-I/usr/include/libdb4,;/-l crypto/s/$/ -Wl,-Bdynamic/;/-l ssl/s/-/-Wl,-static -/' src/Makefile
%__sed -i '/-lssl/s/-/-Wl,-static -/;/-lcrypto/s/crypto/& -Wl,-Bdynamic -lz -ldl/' *-qt.pro
%endif
%endif

%build
%if 0%{?fedora} > 0 || 0%{?centos_version} > 0 || 0%{?rhel_version} > 0
%if 0%{?fedora} <= 19
%__sed -i 's/boost_thread/boost_thread-mt/' *-qt.pro src/Makefile
%endif
qmake-qt4 \
%if 0%{?fedora} > 0
	USE_QRCODE=1 \
%endif
%if 0%{?fedora} <= 20 || 0%{?centos_version} > 0 || 0%{?rhel_version} > 0
	USE_UPNP=- \
%else
	INCLUDEPATH=/usr/include/miniupnpc \
%endif
	QMAKE_CXXFLAGS="%{optflags} -fpermissive -I/usr/include/libdb4 -Wno-narrowing" \
	QMAKE_LFLAGS="%{optflags} -L%{_libdir}/libdb4"
%else
qmake USE_QRCODE=1 QMAKE_CXXFLAGS="%{optflags} -fpermissive -Wno-narrowing" QMAKE_LFLAGS="%{optflags}" INCLUDEPATH=/usr/include/miniupnpc
%endif
%__make %{?_smp_mflags}
%__make -C src INCLUDEPATHS="%{optflags} -fpermissive -I/usr/include/libdb4 -L%{_libdir}/libdb4 -Wno-narrowing" %{?_smp_mflags}

%install
%__install -dm 755 "%{buildroot}%{_bindir}"
%__install -m 0755 %{name}-qt "%{buildroot}%{_bindir}/%{name}"
%__install -m 0755 src/%{name}d "%{buildroot}%{_bindir}"

%if 0%{?suse_version} > 0
%__install -m 0755 "%{S:2}" "%{buildroot}%{_bindir}"
%__install -dm 755 "%{buildroot}%{_sysconfdir}/apparmor.d"
%__install -m 644 "%{S:3}" "%{buildroot}%{_sysconfdir}/apparmor.d/usr.bin.%{name}d-safe"
%suse_update_desktop_file -i %{name}
%else
%__install -dm 755 "%{buildroot}%{_datadir}/applications/"
%__install -m 644 "%{S:1}" "%{buildroot}%{_datadir}/applications/"
%endif
%__install -dm 755 "%{buildroot}%{_datadir}/pixmaps/"
%__install -m 644 src/qt/res/icons/bitcoin.png "%{buildroot}%{_datadir}/pixmaps/%{name}.png"

%__debug_install_post

%files
%defattr(-,root,root,-)
%doc COPYING DESIGN-namecoin.md FAQ.md README.md TODO-namecoin doc/README doc/README_merged-mining.md
%{_bindir}/%{name}d
%if 0%{?suse_version} > 0
%{_bindir}/%{name}d-safe
%config %{_sysconfdir}/apparmor.d/usr.bin.%{name}d-safe
%endif

%files gui
%defattr(-,root,root,-)
%doc COPYING README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%changelog
* Mon Mar 12 2018 ol@infoserver.lv
- Require OpenSSL 1.0 for build in Fedora
* Sun Oct  2 2016 conrad@quisquis.de
- Avoid narrowing error on pchMessageStart initializer
* Sun Oct  2 2016 conrad@quisquis.de
- Better fix for serialization problem with cxx-11
* Sun Oct  2 2016 conrad@quisquis.de
- Added fix for serialization problem with boost-1.61
* Mon Jan 12 2015 conrad@quisquis.de
- Added fix for openssl-1.0.1k
* Thu Dec 18 2014 conrad@quisquis.de
- New upstream
* Tue Nov 18 2014 conrad@quisquis.de
- Fixed build wrt USE_SSL flag
* Sat Sep 13 2014 conrad@quisquis.de
- New upstream
* Thu Sep 11 2014 conrad@quisquis.de
- Improved Fedora openssl patch
* Wed Sep 10 2014 conrad@quisquis.de
- Use system openssl on Fedora >= 20
* Thu Jul 31 2014 conrad@quisquis.de
- Disable UPNP on Fedora due to OBS library inconsistency
* Thu Jun 19 2014 conrad@quisquis.de
- Added missing-return.patch
* Thu Jun 19 2014 conrad@quisquis.de
- Upgrade to new upstream version
* Sat May 31 2014 conrad@quisquis.de
- Fixed .desktop file
* Wed Apr 23 2014 conrad@quisquis.de
- Fixed bashism in namecoind-safe script
- Added libjansson dependency on Debian
- Replaced Ubuntu-13.04 build with -14.04
* Sat Dec 28 2013 conrad@quisquis.de
- Another shot at centos + rhel
* Sat Dec 28 2013 conrad@quisquis.de
- Another shot at centos + rhel
* Tue Dec 24 2013 conrad@quisquis.de
- Another shot at centos + rhel
* Tue Dec 24 2013 conrad@quisquis.de
- Another shot at centos + rhel
* Tue Dec 24 2013 conrad@quisquis.de
- Modification to make fedora-19 build work, too
- Use own static libjansson for RHEL+CentOS
* Tue Dec 24 2013 conrad@quisquis.de
- Modification to make fedora pre-19 build work
* Thu Dec 19 2013 conrad@quisquis.de
- More build mods for fedora, centos + rhel
* Tue Dec 17 2013 conrad@quisquis.de
- Attempt build mods for fedora, centos + rhel
* Fri Nov  1 2013 conrad@quisquis.de
- Upstream bugfix wrt name registration, hard fork @ 150000
* Fri Oct  4 2013 conrad@quisquis.de
- Exclude unused libs from linking
* Thu Oct  3 2013 conrad@quisquis.de
- Fixed various OBS sanity checks
* Thu Oct  3 2013 conrad@quisquis.de
- Fixed syntax error in specfile
- Add license text to debian.copyright
* Thu Oct  3 2013 conrad@quisquis.de
- Suppress static linking
- Minor debian fixes
* Wed Oct  2 2013 conrad@quisquis.de
- Debian: fixed dependency for glib2
- openSUSE: added fix for newer miniupnp
* Wed Oct  2 2013 conrad@quisquis.de
- Debian: added dependencies for libboost-chrono + glib2
- openSUSE: add -fpermissive compiler option
* Wed Oct  2 2013 conrad@quisquis.de
- Fixed build wrt makefile.unix
* Wed Oct  2 2013 conrad@quisquis.de
- Initial project creation
